#!/bin/bash
set -euo pipefail
pids=()

check() {
    if [ ! -d $1 ]; then echo "Error: $1 directory is missing"; exit 1; fi
}

serve() {
    PYTHONDONTWRITEBYTECODE=1 python3 <<EOF & 
PORT = $1
DIR = "$2"

from local import route, static_file, run
import os

@route('/')
def send_root():
    return static_file('index.html', root=DIR)

@route('/<filename:path>')
def send_static(filename):
    if os.path.isdir(os.path.join(DIR, filename)):
        return static_file(os.path.join(filename, 'index.html'), root=DIR)
    else:
        return static_file(filename, root=DIR)

run(host='localhost', port=PORT, debug=True)
EOF
    pids[$1]=$!
}

check      ./local    # don't start subprocessess
check      ./local-s  # if these directories aren't present

serve 8000 ./local    # serve collaboration pages on port 8000
serve 8001 ./local-s  # serve review pages on port 8001

cat <<EOF

    Securepub is a static site.  All state is stored in the browser
    and at Userbase.com so you can always safely kill this script
    with Ctrl-C and/or restart as necessary.

EOF
trap "kill ${pids[*]}" SIGINT SIGTERM EXIT
set -x
wait ${pids[@]}
